@@ -23,6 +23,10 @@ module Rack
 
     DEFAULT_VARY_HEADERS = ['Origin'].freeze
 
+    # All CORS routes need to accept CORS simple headers at all times
+    # {https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Headers}
+    CORS_SIMPLE_HEADERS = ['accept', 'accept-language', 'content-language', 'content-type'].freeze
+
     def initialize(app, opts={}, &block)
       @app = app
       @debug_mode = !!opts[:debug]
@@ -134,7 +138,7 @@ module Rack
           @logger_proc = nil
           logger_proc.call
 
-        elsif defined?(Rails) && Rails.logger
+        elsif defined?(Rails) && Rails.respond_to?(:logger) && Rails.logger
           Rails.logger
 
         elsif env[RACK_LOGGER]
@@ -155,7 +159,7 @@ module Rack
         resource, error = match_resource(env)
         unless resource
           result.miss(error)
-          return {} 
+          return {}
         end
 
         return resource.process_preflight(env, result)
@@ -407,10 +411,14 @@ module Rack
           end
 
           def allow_headers?(request_headers)
-            return false if headers.nil?
-            headers == :any || begin
-              request_headers = request_headers.split(/,\s*/) if request_headers.kind_of?(String)
-              request_headers.all?{|h| headers.include?(h.downcase)}
+            headers = self.headers || []
+            if headers == :any
+              return true
+            end
+            request_headers = request_headers.split(/,\s*/) if request_headers.kind_of?(String)
+            request_headers.all? do |header|
+              header = header.downcase
+              CORS_SIMPLE_HEADERS.include?(header) || headers.include?(header)
             end
           end
 
