@@ -16,7 +16,7 @@ end
 Rack::Test::Methods.class_eval do
   def_delegator :current_session, :options
 end
-  
+
 module MiniTest::Assertions
   def assert_cors_success(response)
   	assert !response.headers['Access-Control-Allow-Origin'].nil?, "Expected a successful CORS response"
@@ -405,6 +405,54 @@ describe Rack::Cors do
     end
   end
 
+  describe 'with headers set to nil' do
+    let(:app) do
+      Rack::Builder.new do
+        use Rack::Cors do
+          allow do
+            origins '*'
+            resource '/', headers: nil
+          end
+        end
+        map('/') do
+          run ->(env) { [200, {'Content-Type' => 'text/html'}, ['hello']] }
+        end
+      end
+    end
+
+    it 'should succeed with CORS simple headers' do
+      preflight_request('http://localhost:3000', '/', :headers => 'Accept')
+      last_response.must_render_cors_success
+    end
+  end
+
+  describe 'with custom allowed headers' do
+    let(:app) do
+      Rack::Builder.new do
+        use Rack::Cors do
+          allow do
+            origins '*'
+            resource '/', headers: []
+          end
+        end
+        map('/') do
+          run ->(env) { [200, {'Content-Type' => 'text/html'}, ['hello']] }
+        end
+      end
+    end
+
+    it 'should succeed with CORS simple headers' do
+      preflight_request('http://localhost:3000', '/', :headers => 'Accept')
+      last_response.must_render_cors_success
+      preflight_request('http://localhost:3000', '/', :headers => 'Accept-Language')
+      last_response.must_render_cors_success
+      preflight_request('http://localhost:3000', '/', :headers => 'Content-Type')
+      last_response.must_render_cors_success
+      preflight_request('http://localhost:3000', '/', :headers => 'Content-Language')
+      last_response.must_render_cors_success
+    end
+  end
+
   protected
     def cors_request(*args)
       path = args.first.is_a?(String) ? args.first : '/'
